@@ -181,6 +181,8 @@ def update_models(all_rest_dict_list):
             re1 = RouteExec.objects.filter(table_big_name=curr_class_name, inspected_from_db=1).all()
             if len(re1)<1:
                 print('skip this table',curr_class_name, len(re1))
+                f2.write(one_line + "\n")
+                continue
             cf = ComputedField.objects.filter(route_exec=re1[0]).all()
             for cfi in cf:
                 f2.write(' ' * one_line_start_space+cfi.func_text.replace('\r\n','\n'))
